@@ -4,7 +4,7 @@ import string
 import sys
 from itertools import chain, product
 
-__version__ = '0.1.5'
+__version__ = '0.1.6'
 
 __all__ = ['braceexpand', 'alphabet', 'UnbalancedBracesError']
 
@@ -87,11 +87,11 @@ def braceexpand(pattern, escape=True):
     UnbalancedBracesError: Unbalanced braces: '{1{2,3}'
 
     # By default, the backslash is the escape character.
-    >>> list(braceexpand(r'{1\{2,3}'))
+    >>> list(braceexpand(r'{1\\{2,3}'))
     ['1{2', '3']
 
     # Setting 'escape' to False disables backslash escaping.
-    >>> list(braceexpand(r'\{1,2}', escape=False))
+    >>> list(braceexpand(r'\\{1,2}', escape=False))
     ['\\\\1', '\\\\2']
 
     """
@@ -196,11 +196,14 @@ def make_int_range(start, end, step=None):
 
 
 def make_char_range(start, end, step=None):
-    step = int(step) if step else 1
+    step = (int(step) or 1) if step else 1
     start = alphabet.index(start)
     end = alphabet.index(end)
-    return alphabet[start:end+1:step] if start < end else \
-           alphabet[start:end-1:-step]
+    if start < end:
+        return alphabet[start:end+1:step]
+    else:
+        end = end or -len(alphabet)
+        return alphabet[start:end-1:-step]
 
 
 escape_re = re.compile(r'\\(.)')
